@@ -98,8 +98,9 @@ class view3D():
         # Temp
         self._points = []
         self._directions = []
-        self.scale = 10
+        self.scale = 1
         self.toggle = None
+        self.size = 10
 
     @property
     def points(self):
@@ -149,7 +150,7 @@ class view3D():
                 r = R.from_matrix(local_orientation)
                 orientation = np.asarray(r.as_euler('xyz', degrees=True))
                 # just added static size of the accelerometer
-                point +=  np.array(+normal) / 2 * 10
+                point +=  np.array(+normal) / 2 * self.size
                 self.acc_callback(point,orientation=orientation)
             else:
                 pass
@@ -490,9 +491,8 @@ class view3D():
         :param fixed_rotation: fixed rotation angle
         :type fixed_rotation: float
         """
-
         i = int(len(self.all_accs_dynamic)+len(self.all_imps_dynamic)+len(self.all_vps_dynamic))
-        size = 10
+        size = self.size
 
         if np.asarray(orientation).all() == None:
             acc = self.create_accelerometer([size/2, size/2, size/2], [0, 0, 0], size=size)
@@ -503,13 +503,13 @@ class view3D():
             rot = r.as_matrix()
 
         self.add_accelerometer(acc)
-        _gg = DynamicPosition(acc, self.plot, i, mesh=self.mesh, size=10,rot = rot,fixed_rotation = fixed_rotation,snap_outward = True)
-        self.plot.add_sphere_widget(_gg.callback, center=_gg.points, color=["k", "r", "g", "b"], radius=10 / 15)
+        _gg = DynamicPosition(acc, self.plot, i, mesh=self.mesh, size=size,rot = rot,fixed_rotation = self.fixed_rotation,snap_outward = True)
+        self.plot.add_sphere_widget(_gg.callback, center=_gg.points, color=["k", "r", "g", "b"], radius=size / 15)
         _gg.translate(point)
         _gg.turn_on = True
         self.all_accs_dynamic.append(_gg)
 
-    def add_acc_dynamic(self, mesh, predefined=None,scale = 1,fixed_rotation = None):
+    def add_acc_dynamic(self, mesh, predefined=None,scale = 1,fixed_rotation = None, size = 10):
         """
         Add a set of predefined accelerometers to the 3D display and toggle the possibility to add
         additional accelerometers.
@@ -523,7 +523,8 @@ class view3D():
         :param fixed_rotation: fixed rotation angle
         :type fixed_rotation: float
         """
-
+        self.size = size
+        self.fixed_rotation = fixed_rotation
         self.mesh = mesh
         self.mesh.compute_normals(auto_orient_normals=True, inplace=True)
 
@@ -535,9 +536,9 @@ class view3D():
             for i, row in predefined.iterrows():
                 point = np.asarray([row["Position_1"] * scale, row["Position_2"] * scale, row["Position_3"] * scale])
                 orientation = np.asarray([row["Orientation_1"], row["Orientation_2"], row["Orientation_3"]])
-                self.acc_callback(point, orientation=orientation,fixed_rotation = fixed_rotation)
+                self.acc_callback(point, orientation=orientation,fixed_rotation = self.fixed_rotation)
         
-        self.plot.add_text('Use right mouse click to add an accelerometer', color="k", font="times",font_size = 10, name="text")
+        self.plot.add_text('Use right mouse click to add an accelerometer, hold the letter T to not snap to mesh.', color="k", font="times",font_size = 10, name="text")
 
 
     def imp_callback(self,point, direction = None,fixed_rotation = None):
@@ -553,22 +554,22 @@ class view3D():
         """
 
         i = int(len(self.all_accs_dynamic)+len(self.all_imps_dynamic)+len(self.all_vps_dynamic))
-        size = 10
+        size = self.size
         if np.asarray(direction).all() == None:
-            imp, _ = self.add_impact([size/2, size/2, size/2], [0, 0, 1], size=10)
+            imp, _ = self.add_impact([size/2, size/2, size/2], [0, 0, 1], size=self.size)
             rot = np.diag([1]*3)
         else:
-            imp, _ = self.add_impact([size/2, size/2, size/2],direction, size=10)
+            imp, _ = self.add_impact([size/2, size/2, size/2],direction, size=self.size)
             rot = rotation_matrix_from_vectors(direction,[0, 0, 1]).T
 
         
-        _gg = DynamicPosition([imp], self.plot, i, mesh=self.mesh, size=10,rot = rot,snap_outward = False, fixed_rotation = fixed_rotation, toggle = "impact")
-        self.plot.add_sphere_widget(_gg.callback, center=_gg.points, color=["k", "r", "g", "b"], radius=10 / 15)
+        _gg = DynamicPosition([imp], self.plot, i, mesh=self.mesh, size=self.size,rot = rot,snap_outward = False, fixed_rotation = self.fixed_rotation, toggle = "impact")
+        self.plot.add_sphere_widget(_gg.callback, center=_gg.points, color=["k", "r", "g", "b"], radius=self.size / 15)
         _gg.translate(point)
         _gg.turn_on = True
         self.all_imps_dynamic.append(_gg)
 
-    def add_imp_dynamic(self, mesh, predefined=None,scale = 1,fixed_rotation = None):
+    def add_imp_dynamic(self, mesh, predefined=None,scale = 1,fixed_rotation = None,size = 10):
         """
         Add a set of predefined impacts to the 3D display and toggle the possibility to add
         additional impacts.
@@ -582,9 +583,11 @@ class view3D():
         :param fixed_rotation: fixed rotation angle
         :type fixed_rotation: float
         """
+        self.size = size
 
         self.mesh = mesh
         self.mesh.compute_normals(auto_orient_normals=True, inplace=True)
+        self.fixed_rotation = fixed_rotation
 
         self.toggle_fun()
         self.toggle = "impact"
@@ -594,9 +597,9 @@ class view3D():
             for i, row in predefined.iterrows():
                 point = np.asarray([row["Position_1"] * scale, row["Position_2"] * scale, row["Position_3"] * scale])
                 direction = np.asarray([row["Direction_1"], row["Direction_2"], row["Direction_3"]])
-                self.imp_callback(point, direction=direction,fixed_rotation = fixed_rotation)
+                self.imp_callback(point, direction=direction,fixed_rotation = self.fixed_rotation)
 
-        self.plot.add_text('Use right mouse click to add an impact', color="k", font="times",font_size = 10, name="text")
+        self.plot.add_text('Use right mouse click to add an impact, hold the letter T to not snap to mesh.', color="k", font="times",font_size = 10, name="text")
 
 
     def vp_callback(self,point,fixed_rotation = None):
@@ -614,7 +617,7 @@ class view3D():
 
         acc, _ = self.add_vp([size/2, size/2, size/2], size=size, opacity=.1)
 
-        _gg = DynamicPosition([acc], self.plot, i, mesh=self.mesh, size=4, snap_outward=False,fixed_rotation = fixed_rotation)
+        _gg = DynamicPosition([acc], self.plot, i, mesh=self.mesh, size=4, snap_outward=False,fixed_rotation = self.fixed_rotation)
         self.plot.add_sphere_widget(_gg.callback, center=_gg.points, color=["k", "r", "g", "b"], radius=4 / 15)
 
         _gg.turn_on = True
@@ -647,7 +650,7 @@ class view3D():
             position = np.asarray([x, y, z]).T
             position *= scale
             for pos in position:
-                self.vp_callback(pos,fixed_rotation = fixed_rotation)
+                self.vp_callback(pos,fixed_rotation = self.fixed_rotation)
 
         self.plot.enable_point_picking(callback=self.vp_callback, color="r", show_message="", show_point=False)
         self.plot.add_text("Press P too add a VP (hold down letter T to disable snapping to mesh).", font_size=10, color="k", font="times", name="text")
@@ -1080,10 +1083,12 @@ class DynamicPosition():
     def __init__(self, objects, p, N, mesh=None, snap_outward=True, size=1, rot = np.diag([1]*3), fixed_rotation = None,toggle = "acc"):
         # set size and static points
         self.size = size
-        self.points = np.array([[size / 2, size / 2, size / 2],
-                                [0, size / 2, size / 2],
-                                [size / 2, 0, size / 2],
-                                [size / 2, size / 2, 0]])
+        self.points = np.array([[0.0, 0.0, 0.0],
+                                       [0.5, 0, 0],
+                                       [0, 0.5, 0],
+                                       [0, 0, 0.5]]) * size
+
+        self.points = (rot.T @ (self.points).T).T + size/2
 
         # Creates a bounding box
         self.box = pv.Box((-size, size, -size, size, -size, size))
@@ -1091,7 +1096,6 @@ class DynamicPosition():
         self.box.points /= 2
 
         self.fixed_theta = fixed_rotation
-
         # defines the objects
         objects.insert(0, self.box)
         self.objects = objects
@@ -1106,9 +1110,9 @@ class DynamicPosition():
 
         # local positions of the point widgets
         self.local_widgets = np.array([[0.0, 0.0, 0.0],
-                                       [-0.5, 0, 0],
-                                       [0, -0.5, 0],
-                                       [0, 0, -0.5]]) * size
+                                       [0.5, 0, 0],
+                                       [0, 0.5, 0],
+                                       [0, 0, 0.5]]) * size
 
         # local normals on which the snapping happens
         self.local_normals = np.asarray([[1, 0, 0],
@@ -1128,8 +1132,8 @@ class DynamicPosition():
                                       [0, 0, -1]]).T * ray_size
 
         # allign everything with new rotational matrix
-        self.local_orientation = (rot @ (self.local_orientation))
-        self.local_widgets = (rot @ (self.local_widgets).T).T
+        self.local_orientation = rot @ (self.local_orientation)
+        self.local_widgets = (rot.T @ (self.local_widgets).T).T
         self.local_normals = rot @ self.local_normals
         self.local_rays = rot @ self.local_rays
 
@@ -1146,6 +1150,7 @@ class DynamicPosition():
         self.p = p
         self.toggle = toggle
 
+
     def get_pos_orient(self, euler_angles=False, one_dir=None, eps=1e-10,scale = 1):
         """
         Extracts the positional and orientational data of the object.
@@ -1158,7 +1163,7 @@ class DynamicPosition():
         :type eps: float, optional
         :return:
         """
-
+        
         position = self.box.center_of_mass()
 
         # return euler_angles
@@ -1192,8 +1197,10 @@ class DynamicPosition():
         :type snap: bool, optional
         """
 
-		# option B
-        if snap:
+        # default option - no rotation
+        rot = np.diag([1., 1., 1.])
+
+        if snap and not (kb.is_pressed('t')):
             direction = np.asarray(point) - np.asarray(self.p.camera_position[0])
             direction = direction / np.linalg.norm(direction)
             start = point - 1000 * direction
@@ -1201,7 +1208,7 @@ class DynamicPosition():
             points, ind = self.mesh.ray_trace(start, end, first_point=True)
 
             # fast upgrade to option B
-            if self.snap_outward:
+            if self.snap_outward and points.size != 0:
                 f = self.mesh.cell_normals[int(ind)]
                 point = points - f / 2 * self.size
                 direction = np.asarray(point) - np.asarray(self.p.camera_position[0])
@@ -1210,9 +1217,6 @@ class DynamicPosition():
                 end = point + 10000 * direction
                 points, ind = self.mesh.ray_trace(start, end, first_point=True)
 
-            # default option - no rotation
-            rot = np.diag([1., 1., 1.])
-
             # if there is an intersection and if "t" is not pressed go forward
             if points.size != 0 and not (kb.is_pressed('t')):
                 # find the nearest normal
@@ -1241,7 +1245,6 @@ class DynamicPosition():
                 #    rot = rotation_matrix_from_vectors(np.asarray([0.,0.,1.]).T, np.asarray([0.,0.,1.]).T)
                 #else:
                 rot = rotation_matrix_from_vectors(t, f)
-
         # move everything to a new location
         _new = point - self.box.center_of_mass()
 
@@ -1262,10 +1265,10 @@ class DynamicPosition():
             self.local_orientation = (rot @ (self.local_orientation))
             self.local_normals = rot @ self.local_normals
             self.local_rays = rot @ self.local_rays
-
             # rotate everything within accelerometer
             for item in self.objects:
                 item.points = (rot @ (item.points - t_new).T).T + t_new
+            
 
         else:
             for item in self.objects:
@@ -1295,15 +1298,17 @@ class DynamicPosition():
                 _vec2 = (np.asarray(self.local_widgets[i, :]))
 
                 # define the rotational matrix based on angle of rotation
-                theta = angle(_vec1, _vec2)
+                #theta = angle(_vec1, _vec2)
+                theta = -1*angle(_vec1, _vec2)
 
                 # overwrite calculated rotational angle
                 if self.fixed_theta != None:
                     theta =  self.fixed_theta*(np.pi/180)
 
-                rot = M(self.local_orientation[i - 1, :], theta)
-
-                # rotate everything within accelerometer
+                #rot = M(self.local_orientation[i - 1, :], theta)
+                rot = M(_vec2, theta)
+                
+                                # rotate everything within accelerometer
                 for item in self.objects:
                     item.points = (rot @ (item.points - _new).T).T + _new
 
